@@ -74,12 +74,19 @@ class MainWindow(QtGui.QMainWindow):
 	def addT298(self):
 			self.ui.spnSec.setValue(298)
 	def kall(self):
-			bus = dbus.SystemBus()
-			csd_call = dbus.Interface(bus.get_object('com.nokia.csd',
+			if (self.ui.edtPhone.text().isEmpty()):
+				bus = dbus.SystemBus()
+				iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                        '/org/freedesktop/Notifications'),
+                                        'org.freedesktop.Notifications')
+				iface.SystemNoteInfoprint("Can't Kall with an empty phone number!")
+			else:
+				bus = dbus.SystemBus()
+				csd_call = dbus.Interface(bus.get_object('com.nokia.csd',
                                            '/com/nokia/csd/call'),
                                            'com.nokia.csd.Call')
-			csd_call.CreateWith(str(self.ui.edtPhone.text()), dbus.UInt32(0))
-			self.single()
+				csd_call.CreateWith(str(self.ui.edtPhone.text()), dbus.UInt32(0))
+				self.single()
 			
 	def single(self):
 		self.timer.singleShot(self.ui.spnSec.value()*1000, self.hangUp)	
@@ -96,6 +103,10 @@ class MainWindow(QtGui.QMainWindow):
                                            'com.nokia.csd.Call')
 				csd_call.CreateWith(str(self.ui.edtPhone.text()), dbus.UInt32(0))
 				self.single()
+				iface = dbus.Interface(bus.get_object('org.freedesktop.Notifications',
+                                        '/org/freedesktop/Notifications'),
+                                        'org.freedesktop.Notifications')
+				iface.SystemNoteInfoprint("Redialing..")
 			
 if __name__ == "__main__":
         #This function means this was run directly, not called from another python file.
